@@ -1,4 +1,5 @@
-from .mw_plot_classes import *
+from mw_plot.mw_plot_matplotlib import *
+from mw_plot.mw_plot_bokeh import *
 from pkg_resources import get_distribution
 from astropy.coordinates import SkyCoord, ICRS
 import astropy.units as u
